=========================
Developing base templates
=========================

Fork a base template or create your own
---------------------------------------

Base templates should consist of `_base/base.py` and any additional files.


Defining filters and context processors in `_base/base.py`
----------------------------------------------------------
